KM3NeT database library
=======================

.. image:: https://git.km3net.de/km3py/km3db/badges/master/pipeline.svg
    :target: https://git.km3net.de/km3py/km3db/pipelines

.. image:: https://git.km3net.de/km3py/km3db/badges/master/coverage.svg
    :target: https://km3py.pages.km3net.de/km3db/coverage

.. image:: https://examples.pages.km3net.de/km3badges/docs-latest-brightgreen.svg
    :target: https://km3py.pages.km3net.de/km3db

